#!/usr/bin/env python

import iixr

numbers = [12345678, 0, 1, 127, 128, 255, 256]

f = open("test", "wb")
w = iixr.FileWriter(f)
for number in numbers:
    w.write_number(number)
w.close()

f = open("test", "rb")
r = iixr.FileReader(f)
for number in numbers:
    n = r.read_number()
    print number == n, number, n
r.close()

all_doc_positions = [
    [
        (123, [1, 3, 5, 15, 25]),
        (124, [0, 100])
    ],
    [
        (78, [9]),
        (196, [10, 11])
    ]
    ]

f = open("test", "wb")
w = iixr.PositionWriter(f)
for doc_positions in all_doc_positions:
    for docnum, positions in doc_positions:
        w.write_positions(docnum, positions)
    w.reset()
w.close()

f = open("test", "rb")
r = iixr.PositionReader(f)
for doc_positions in all_doc_positions:
    for docnum, positions in doc_positions:
        d, p = r.read_positions()
        print docnum == d, docnum, d
        print positions == p, positions, p
    r.reset()
r.close()

f = open("test", "wb")
w = iixr.PositionWriter(f)
offsets = []
for doc_positions in all_doc_positions:
    offsets.append(
        w.write_all_positions(doc_positions)
        )
w.close()

f = open("test", "rb")
r = iixr.PositionReader(f)
offsets.reverse()
all_doc_positions.reverse()
for offset, doc_positions in zip(offsets, all_doc_positions):
    dp = r.read_all_positions(offset)
    print doc_positions == dp, doc_positions, dp
r.close()

terms = [
    ("aardvark",  100000123),
    ("anteater",  100000456),
    ("badger",    100000789),
    ("bull",     1000001234),
    ("bulldog",  1000002345),
    ("cat",      1000003456)
    ]

f = open("test", "wb")
w = iixr.TermWriter(f)
for term, offset in terms:
    w.write_term(term, offset)
w.close()

f = open("test", "rb")
r = iixr.TermReader(f)
for term, offset in terms:
    t, o = r.read_term()
    print term == t, term, t
    print offset == o, offset, o
r.close()

indexed_terms = [
    ("aardvark",  100000123, 200000321),
    ("anteater",  100000456, 200000654),
    ("badger",    100000789, 200000987),
    ("bull",     1000001234, 200004321),
    ("bulldog",  1000002345, 200005432),
    ("cat",      1000003456, 200006543)
    ]

f = open("test", "wb")
w = iixr.TermIndexWriter(f)
for term, offset, info_offset in indexed_terms:
    w.write_term(term, offset, info_offset)
w.close()

f = open("test", "rb")
r = iixr.TermIndexReader(f)
for term, offset, info_offset in indexed_terms:
    t, o, i = r.read_term()
    print term == t, term, t
    print offset == o, offset, o
    print info_offset == i, info_offset, i
r.close()

f = open("test", "wb")
w = iixr.TermWriter(f)
f2 = open("testI", "wb")
w2 = iixr.TermIndexWriter(f2)
f3 = open("testP", "wb")
w3 = iixr.PositionWriter(f3)
wd = iixr.TermDictionaryWriter(w, w2, w3, 3)
for term, offset in terms:
    wd.write_term(term, offset)
wd.close()

f = open("test", "rb")
r = iixr.TermReader(f)
f2 = open("testI", "rb")
r2 = iixr.TermIndexReader(f2)
f3 = open("testP", "rb")
r3 = iixr.PositionReader(f3)
rd = iixr.TermDictionaryReader(r, r2, r3)
terms_reversed = terms[:]
terms_reversed.reverse()
for term, offset in terms_reversed:
    o = rd.find(term)
    print offset == o, offset, o
for term in ("dog", "dingo"):
    o = rd.find(term)
    print o is None, o
rd.close()

terms_with_positions = [
    ("aardvark",  [(1, [2, 45, 96]), (20, [13])]),
    ("anteater",  [(1, [43, 44])]),
    ("badger",    [(7, [2, 22, 196]), (19, [55, 1333]), (21, [0])]),
    ("bull",      [(6, [128]), (16, [12])]),
    ("bulldog",   [(43, [17, 19, 256, 512])]),
    ("cat",       [(123, [12, 145, 196]), (1200, [113])])
    ]

f = open("test", "wb")
w = iixr.TermWriter(f)
f2 = open("testI", "wb")
w2 = iixr.TermIndexWriter(f2)
f3 = open("testP", "wb")
w3 = iixr.PositionWriter(f3)
wd = iixr.TermDictionaryWriter(w, w2, w3, 3)
for term, doc_positions in terms_with_positions:
    wd.write_term_positions(term, doc_positions)
wd.close()

f = open("test", "rb")
r = iixr.TermReader(f)
f2 = open("testI", "rb")
r2 = iixr.TermIndexReader(f2)
f3 = open("testP", "rb")
r3 = iixr.PositionReader(f3)
rd = iixr.TermDictionaryReader(r, r2, r3)
terms_reversed = terms_with_positions[:]
terms_reversed.reverse()
for term, doc_positions in terms_reversed:
    dp = rd.find_positions(term)
    print doc_positions == dp, doc_positions, dp
for term in ("dog", "dingo"):
    dp = rd.find_positions(term)
    print dp is None, dp
rd.close()

# vim: tabstop=4 expandtab shiftwidth=4
